Type Definition deadpool_lapin::ConfigError[][src]

pub type ConfigError = Infallible;
This error is returned if there is something wrong with the lapin configuration.

This is just a type alias to Infallible at the moment as there is no validation happening at the configuration phase.