Crate deadpool_lapin[−][src]
Deadpool for Lapin

Deadpool is a dead simple async pool for connections and objects of any type.
This crate implements a deadpool
manager for lapin.
Features
| Feature | Description | Extra dependencies | Default |
|---|---|---|---|
rt_tokio_1 | Enable support for tokio crate | deadpool/rt_tokio_1 | yes |
rt_async-std_1 | Enable support for async-std crate | deadpool/rt_async-std_1 | no |
serde | Enable support for serde crate | deadpool/serde, serde/derive | no |
Example with tokio-amqp crate
use std::sync::Arc;
use deadpool_lapin::{Config, Manager, Pool, Runtime};
use deadpool_lapin::lapin::{
options::BasicPublishOptions,
BasicProperties,
};
use tokio_amqp::LapinTokioExt as _;
#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
let mut cfg = Config::default();
cfg.url = Some("amqp://127.0.0.1:5672/%2f".into());
let pool = cfg.create_pool(Some(Runtime::Tokio1))?;
for _ in 1..10 {
let mut connection = pool.get().await?;
let channel = connection.create_channel().await?;
channel.basic_publish(
"",
"hello",
BasicPublishOptions::default(),
b"hello from deadpool".to_vec(),
BasicProperties::default(),
).await?;
}
Ok(())
}Example with config, dotenv and tokio-amqp crate
use std::sync::Arc;
use deadpool_lapin::Runtime;
use deadpool_lapin::lapin::{
options::BasicPublishOptions,
BasicProperties,
};
use dotenv::dotenv;
#[derive(Debug, serde::Deserialize)]
struct Config {
#[serde(default)]
amqp: deadpool_lapin::Config
}
impl Config {
pub fn from_env() -> Result<Self, config::ConfigError> {
let mut cfg = config::Config::new();
cfg.merge(config::Environment::new().separator("__"))?;
cfg.try_into()
}
}
#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
dotenv().ok();
let mut cfg = Config::from_env().unwrap();
let pool = cfg.amqp.create_pool(Some(Runtime::Tokio1)).unwrap();
for _ in 1..10 {
let mut connection = pool.get().await?;
let channel = connection.create_channel().await?;
channel.basic_publish(
"",
"hello",
BasicPublishOptions::default(),
b"hello from deadpool".to_vec(),
BasicProperties::default(),
).await?;
}
Ok(())
}License
Licensed under either of
- Apache License, Version 2.0 (LICENSE-APACHE or http://www.apache.org/licenses/LICENSE-2.0)
- MIT license (LICENSE-MIT or http://opensource.org/licenses/MIT)
at your option.
Re-exports
pub use lapin;Structs
Configuration object.
Manager for creating and recycling lapin::Connection.
Statistics regarding an object returned by the pool
Pool configuration.
The current pool status.
Enums
Enumeration for picking a runtime implementation.
Type Definitions
Type alias for using deadpool::managed::BuildError with lapin.
This error is returned if there is something wrong with the lapin configuration.
Type alias for [‘Object’]
Type alias for using deadpool::managed::CreatePoolError with lapin.
Type alias for using deadpool::managed::Hook with lapin.
Type alias for using deadpool::managed::HookError with lapin.
Type alias for using deadpool::managed::HookErrorCause with lapin.
Type alias for using deadpool::managed::Object with lapin.
Type alias for using deadpool::managed::Pool with lapin.
Type alias for using deadpool::managed::PoolBuilder with lapin.
Type alias for using deadpool::managed::PoolError with lapin.